Token

Enum Token 

pub enum Token {
Show 27 variants Identifier(String), NameRef(String), ValueRef(String), Eq, Ne, Lt, Le, Gt, Ge, Plus, Minus, And, Or, Not, Between, In, Set, Remove, Add, Delete, LParen, RParen, LBracket, RBracket, Dot, Comma, Number(String),
}

Variants



Identifier(String)



NameRef(String)



ValueRef(String)



Eq



Ne



Lt



Le



Gt



Ge



Plus



Minus



And



Or



Not



Between



In



Set



Remove



Add



Delete



LParen



RParen



LBracket



RBracket



Dot



Comma



Number(String)